.. image:: https://img.shields.io/pypi/v/django-github-webhooks
    :target: https://pypi.org/project/django-github-webhooks/
    :alt: PyPI

.. image:: https://img.shields.io/pypi/djversions/django-github-webhooks
    :alt: PyPI - Django Version

.. image:: https://github.com/OpenWiden/django-github-webhooks/workflows/Tests/badge.svg?branch=master
    :target: https://github.com/OpenWiden/django-github-webhooks/workflows/Tests/badge.svg?branch=master
    :alt: Tests passed

.. image:: https://codecov.io/gh/OpenWiden/django-github-webhooks/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/OpenWiden/django-github-webhooks
    :alt: Code coverage

.. image:: https://readthedocs.org/projects/django-github-webhooks/badge/?version=latest
    :target: https://django-github-webhooks.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/OpenWiden/django-github-webhooks/shield.svg
     :target: https://pyup.io/repos/github/OpenWiden/django-github-webhooks/
     :alt: Updates

===============
GitHub webhooks
===============

GitHub webhooks for Django.

* Documentation: https://django-github-webhooks.readthedocs.io/en/latest/

Features
--------
* Python >= 3.7
* Django>=2.1
* Full tested
* Easily extendable
